@@ -1,5 +1,4 @@
 from django.conf.urls import patterns, url
-from silk.views.documentation import DocumentationView
 
 from silk.views.profile_detail import ProfilingDetailView
 from silk.views.profiling import ProfilingView
@@ -23,6 +22,6 @@ urlpatterns = patterns('silk.views',
                        url(r'^/profile/(?P<profile_id>[0-9]+)/$', ProfilingDetailView.as_view(), name='profile_detail'),
                        url(r'^/profile/(?P<profile_id>[0-9]+)/sql/$', SQLView.as_view(), name='profile_sql'),
                        url(r'^/profile/(?P<profile_id>[0-9]+)/sql/(?P<sql_id>[0-9]+)/$', SQLDetailView.as_view(), name='profile_sql_detail'),
-                       url(r'^/profiling/$', ProfilingView.as_view(), name='profiling'),
-                       url(r'^/documentation/$', DocumentationView.as_view(), name='documentation'))
+                       url(r'^/profiling/$', ProfilingView.as_view(), name='profiling'))
+
 
